@@ -1,4 +1,7 @@
 package HTML::FormFu::Model::DBIC;
+{
+  $HTML::FormFu::Model::DBIC::VERSION = '1.01';
+}
 use strict;
 use warnings;
 use base 'HTML::FormFu::Model';
@@ -10,9 +13,6 @@ use Scalar::Util qw( blessed );
 use Storable qw( dclone );
 use Carp qw( croak );
 
-our $VERSION = '0.09010';
-$VERSION = eval $VERSION;
-
 sub options_from_model {
     my ( $self, $base, $attrs ) = @_;
 
@@ -956,6 +956,8 @@ sub _save_multi_value_fields_many_to_many {
 
             my $config = $field->model_config;
 
+            next if $config->{read_only};
+
             my ($pk) = $config->{default_column}
                 || $related->result_source->primary_columns;
 
